{% extends "base.html" %}
{% import "macros.html" as macros %}

{% block title %}Thread Renderer{% endblock %}

{% block content %}
    {{ macros.content_item(content, is_thread=True, forum_name=forum, forum_icon_url=forum_icon_url) }}
{% endblock %}
